@@ -6,6 +6,15 @@ from .exception import PSPException  # noqa: F401
 from .widget import PerspectiveWidget  # noqa: F401
 from .web import PerspectiveHTTPMixin  # noqa: F401
 from ._version import VERSION as __version__  # noqa: F401
+try:
+    from .table import *  # noqa: F401, F403
+except ImportError:
+    pass
+
+try:
+    from .node import *  # noqa: F401, F403
+except ImportError:
+    pass
 
 # export `plot` and `grid` functions
 plot = psp
