@@ -42,7 +42,7 @@ class TestTypedetect:
         df = pd.DataFrame([1, 2])
         o = type_detect(df)
 
-        expected = [{"index": 0, 0: 1}, {"index": 1, 0: 2}]
+        expected = {0: [1, 2], 'index': [0, 1]}
         print(o.data)
         print(expected)
         assert o.data == expected
@@ -52,7 +52,7 @@ class TestTypedetect:
         df = pd.DataFrame([1, 2])
         o = type_detect(df[0])
 
-        expected = [{"index": 0, 0: 1}, {"index": 1, 0: 2}]
+        expected = {0: [1, 2], 'index': [0, 1]}
         print(o.data)
         print(expected)
         assert o.data == expected
