@@ -16,17 +16,20 @@ class View(Enum):
     SUNBURST = 'sunburst'  # highcharts
     HEATMAP = 'heatmap'  # highcharts
 
-    YAREA_D3 = 'd3_y_area'  # d3fc
+    YBAR_D3 = 'd3_y_bar'  # d3fc
     XBAR_D3 = 'd3_x_bar'  # d3fc
+    YLINE_D3 = 'd3_y_line'  # d3fc
+    YAREA_D3 = 'd3_y_area'  # d3fc
+    YSCATTER_D3 = 'd3_y_scatter'  # d3fc
+    XYSCATTER_D3 = 'd3_xy_scatter'  # d3fc
+    TREEMAP_D3 = 'd3_treemap'  # d3fc
+    SUNBURST_D3 = 'd3_sunburst'  # d3fc
+    HEATMAP_D3 = 'd3_heatmap'  # d3fc
+
     CANDLESTICK = 'd3_candlestick'  # d3fc
     CANDLESTICK_D3 = 'd3_candlestick'  # d3fc
-    HEATMAP_D3 = 'd3_heatmap'  # d3fc
-    YLINE_D3 = 'd3_y_line'  # d3fc
     OHLC = 'd3_ohlc'  # d3fc
     OHLC_D3 = 'd3_ohlc'  # d3fc
-    SUNBURST_D3 = 'd3_sunburst'  # d3fc
-    XYSCATTER_D3 = 'd3_xy_scatter'  # d3fc
-    YSCATTER_D3 = 'd3_y_scatter'  # d3fc
 
     @staticmethod
     def options():
